===============================
networking-h3c
===============================

H3C Vendor Code for OpenStack Neutron to integrate with H3C SDN controller

Please fill here a long description which must be at least 3 lines wrapped on
80 cols, so that distribution package maintainers can use it in their packages.
Note that this is a hard requirement.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/networking-h3c
* Source: http://git.openstack.org/cgit/openstack/networking-h3c
* Bugs: http://bugs.launchpad.net/networking-h3c

Features
--------

* TODO
